/*
 * @(#)SmtpSshExample.java
 *
 * Copyright (c) JSCAPE LLC.
 *
 * This software is the confidential and proprietary information of
 * JSCAPE. ("Confidential Information").  You shall not disclose such
 * Confidential Information and shall use it only in accordance with
 * the terms of the license agreement you entered into with JSCAPE.
 */

import com.jscape.inet.smtp.*;
import com.jscape.inet.smtpssh.*;
import com.jscape.inet.ssh.util.*;
import com.jscape.inet.email.*;
import com.jscape.inet.mime.MimeException;
import java.io.*;

public class SmtpSshExample extends SmtpAdapter {
    SshParameters sshParams;
    
    public SmtpSshExample(SshParameters sshParams) {
    	this.sshParams = sshParams;
    }	
	
    public void sendMessage(String hostname, String to, String from, String subject, String body) throws SmtpException, 
    MimeException {
        // create instance and add listener
        SmtpSsh smtp = new SmtpSsh(sshParams,hostname);
        smtp.addSmtpListener(this);
        smtp.setDebug(true);
        
        // connect to mail server
        smtp.connect();
        
        // create email message
        EmailMessage email = new EmailMessage();
        email.setTo(to);
        email.setFrom(from);
        email.setSubject(subject);
        email.setBody(body);
        
        // send email message
        smtp.send(email);
        
        // disconnect from server
        smtp.disconnect();
    }
    
    // capture connect event
    public void connected(SmtpConnectedEvent evt) {
        System.out.println("Connected to SMTP server: " + evt.getHostname());
    }
    
    // capture disconnect event
    public void disconnected(SmtpDisconnectedEvent evt) {
        System.out.println("Disconnected from SMTP server: " + evt.getHostname());
    }   
    
    public static void main(String[] args) {
        String hostname;
        String to;
        String from;
        String subject;
        String body;
        String sshHostname;
        String sshUsername;
        String sshPassword;
        
        try {
            BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));            
            System.out.print("Enter SSH hostname (e.g. ssh.myserver.com): ");
            sshHostname = reader.readLine();
            
            System.out.print("Enter SSH username (e.g. jsmith): ");
            sshUsername = reader.readLine();
            
            System.out.print("Enter SSH password (e.g. secret): ");
            sshPassword = reader.readLine();
            
            // create SSH connection parameters
            SshParameters sshParams = new SshParameters(sshHostname,sshUsername,sshPassword);
            
            System.out.print("Enter Smtp hostname (e.g. mail.domain.com): ");
            hostname = reader.readLine();
            System.out.print("Enter To address (e.g. recipient@domain.com): ");
            to = reader.readLine();
            System.out.print("Enter From address (e.g. sender@domain.com): ");
            from = reader.readLine();
            System.out.print("Enter Subject (e.g. Hello World): ");
            subject = reader.readLine();
            System.out.print("Enter Message Body (e.g. Just saying hi!): ");
            body = reader.readLine();
            SmtpSshExample example = new SmtpSshExample(sshParams);
            example.sendMessage(hostname,to,from,subject,body);
        }
        catch(Exception e) {
            e.printStackTrace();
        }
    }
}

